<?php

class Products_model extends CI_Model
{

    public function __construct()
    {
        parent::__construct();
    }

    public function deleteProduct($id)
    {
        $this->db->trans_begin();
        $this->db->where('for_id', $id);
        if (!$this->db->delete('products_translations')) {
            log_message('error', print_r($this->db->error(), true));
        }

        $this->db->where('id', $id);
        if (!$this->db->delete('products')) {
            log_message('error', print_r($this->db->error(), true));
        }
        if ($this->db->trans_status() === FALSE) {
            $this->db->trans_rollback();
            show_error(lang('database_error'));
        } else {
            $this->db->trans_commit();
        }
    }

    public function productsCount($search_title = null, $category = null)
    {
        if ($search_title != null) {
            $search_title = trim($this->db->escape_like_str($search_title));
            $this->db->where("(products_translations.title LIKE '%$search_title%')");
        }
        if ($category != null) {
            $this->db->where('shop_categorie', $category);
        }
        $this->db->join('products_translations', 'products_translations.for_id = products.id', 'left');
        $this->db->where('products_translations.abbr', MY_DEFAULT_LANGUAGE_ABBR);
        return $this->db->count_all_results('products');
    }

    public function getProducts($limit, $page, $search_title = null, $orderby = null, $category = null, $vendor = null)
    {
        if ($search_title != null) {
            $search_title = trim($this->db->escape_like_str($search_title));
            $this->db->where("(products_translations.title LIKE '%$search_title%')");
        }
        if ($orderby !== null) {
            $ord = explode('=', $orderby);
            if (isset($ord[0]) && isset($ord[1])) {
                $this->db->order_by('products.' . $ord[0], $ord[1]);
            }
        } else {
            $this->db->order_by('products.position', 'asc');
        }
        if ($category != null) {
            $this->db->where('shop_categorie', $category);
        }
        if ($vendor != null) {
            $this->db->where('vendor_id', $vendor);
        }
        $this->db->join('vendors', 'vendors.id = products.vendor_id', 'left');
        $this->db->join('products_translations', 'products_translations.for_id = products.id', 'left');
        $this->db->where('products_translations.abbr', MY_DEFAULT_LANGUAGE_ABBR);
        $query = $this->db->select('vendors.name as vendor_name, vendors.id as vendor_id, products.*, products_translations.title, products_translations.description, products_translations.price, products_translations.old_price, products_translations.abbr, products.url, products_translations.for_id, products_translations.basic_description')->get('products', $limit, $page);
        return $query->result();
    }

    public function numShopProducts()
    {
        return $this->db->count_all_results('products');
    }

    public function getOneProduct($id)
    {
        $this->db->select('vendors.name as vendor_name, vendors.id as vendor_id, products.*, products_translations.price, products_translations.dis_price as dis_price, products_translations.batch_no, products_translations.mfd_date, products_translations.exp_date, products_translations.title, products_translations.old_price');
        $this->db->where('products.id', $id);
        $this->db->join('vendors', 'vendors.id = products.vendor_id', 'left');
        $this->db->join('products_translations', 'products_translations.for_id = products.id', 'inner');
        $this->db->where('products_translations.abbr', MY_DEFAULT_LANGUAGE_ABBR);
        $query = $this->db->get('products');
        if ($query->num_rows() > 0) {
            return $query->row_array();
        } else {
            return false;
        }
    }

    public function productStatusChange($id, $to_status)
    {
        $this->db->where('id', $id);
        $result = $this->db->update('products', array('visibility' => $to_status));
        return $result;
    }

    public function setContribution($post)
	{
		if (!$this->db->insert('donation', array(
					'first_name' => $post['name'],
					'address' => $post['address'],
					'amount' => $post['amount'],
					'donation_mode' => $post['paymode'],

					'status' => '1',
					'for_donat_id' => '1'
				))) {
			log_message('error', print_r($this->db->error(), true));
		}
		$id = $this->db->insert_id();
		return $id;
		
	}
	
    public function setProduct($post, $id = 0)
    {
        if (!isset($post['brand_id'])) {
            $post['brand_id'] = null;
        }
        if (!isset($post['virtual_products'])) {
            $post['virtual_products'] = null;
        }
        $this->db->trans_begin();
        $this->db->where('for_user_id', $id);
        $result = $this->db->get('users_public_profile');

        $is_update = false;
        if (is_null($result)) {
            if (!$this->db->insert('users_public_profile', array(
                        'name' => $post['name'],
                        'for_user_id' => $id,
                        'age' => $post['age'],
                        'gender' => $post['gender'],
                        'image' => $post['image'],
                        'per_address' => $post['peradd'],
                        'cur_address' => $post['curadd'],
                        'description' => $post['description'],
                        'time_update' => time(),
                        'folder' => $post['folder']
                    ))) {
                log_message('error', print_r($this->db->error(), true));
            }
            $id = $this->db->insert_id();

            $this->db->where('id', $id);
            if (!$this->db->update('users_public_profile', array(
                        'url' => except_letters($_POST['name'][$myTranslationNum]) . '_' . $id
                    ))) {
                log_message('error', print_r($this->db->error(), true));
            }



        } /*else {
            /*
             * Lets get what is default tranlsation number
             * in titles and convert it to url
             * We want our plaform public ulrs to be in default 
             * language that we use
             */
            /*$is_update = true;
            if (!$this->db->where('for_user_id', $id)->update('users_public_profile', array(
                        'image' => $post['image'],
                        'name' => $post['name'],
                        'age' => $post['age'],
                        'gender' => $post['gender'],
                        'per_address' => $post['peradd'],
                        'cur_address' => $post['curadd'],
                        'description' => $post['description']
                        //'time_update' => time()
                    ))) {
                log_message('error', print_r($this->db->error(), true));
            }
        }*/
        //$this->setProductTranslation($post, $id, $is_update);
        if ($this->db->trans_status() === FALSE) {
            $this->db->trans_rollback();
            show_error(lang('database_error'));
        } else {
            $this->db->trans_commit();
        }
    }

    private function setProductTranslation($post, $id, $is_update)
    {
        $i = 0;
        $current_trans = $this->getTranslations($id);
        foreach ($post['translations'] as $abbr) {
            $arr = array();
            $emergency_insert = false;
            if (!isset($current_trans[$abbr])) {
                $emergency_insert = true;
            }
			/*if (!isset($post['batch_no'])) {
				$post['batch_no'] = null;
			}
			if (!isset($post['mfd_date'])) {
				$post['mfd_date'] = null;
			}
			if (!isset($post['exp_date'])) {
				$post['exp_date'] = null;
			}*/
            $post['title'][$i] = str_replace('"', "'", $post['title'][$i]);
            $post['price'][$i] = str_replace(' ', '', $post['price'][$i]);
            $post['price'][$i] = str_replace(',', '.', $post['price'][$i]);
            $post['price'][$i] = preg_replace("/[^0-9,.]/", "", $post['price'][$i]);
            $post['old_price'][$i] = str_replace(' ', '', $post['old_price'][$i]);
            $post['old_price'][$i] = str_replace(',', '.', $post['old_price'][$i]);
            $post['old_price'][$i] = preg_replace("/[^0-9,.]/", "", $post['old_price'][$i]);
            $post['dis_price'][$i] = str_replace(' ', '', $post['dis_price'][$i]);
            $post['dis_price'][$i] = str_replace(',', '.', $post['dis_price'][$i]);
            $post['dis_price'][$i] = preg_replace("/[^0-9,.]/", "", $post['dis_price'][$i]);
            $post['batch_no'][$i] = str_replace('"', "'", $post['batch'][$i]);
            $post['mfd_date'][$i] = str_replace('"', "'", $post['mfd_dt'][$i]);
            $post['exp_date'][$i] = str_replace('"', "'", $post['exp_dt'][$i]);
            $arr = array(
                'title' => $post['title'][$i],
                'basic_description' => $post['basic_description'][$i],
                'description' => $post['description'][$i],
                'price' => $post['price'][$i],
                'old_price' => $post['old_price'][$i],
                'abbr' => $abbr,
                'for_id' => $id,
                'dis_price' => $post['dis_price'][$i],
                'batch_no' => $post['batch_no'][$i],
                'mfd_date' => $post['mfd_date'][$i],
                'exp_date' => $post['exp_date'][$i]
            );
            if ($is_update === true && $emergency_insert === false) {
                $abbr = $arr['abbr'];
                unset($arr['for_id'], $arr['abbr'], $arr['url']);
                if (!$this->db->where('abbr', $abbr)->where('for_id', $id)->update('products_translations', $arr)) {
                    log_message('error', print_r($this->db->error(), true));
                }
            } else {
                if (!$this->db->insert('products_translations', $arr)) {
                    log_message('error', print_r($this->db->error(), true));
                }
            }
            $i++;
        }
    }

    public function getTranslations($id)
    {
        $this->db->where('for_id', $id);
        $query = $this->db->get('products_translations');
        $arr = array();
        foreach ($query->result() as $row) {
            $arr[$row->abbr]['title'] = $row->title;
            $arr[$row->abbr]['basic_description'] = $row->basic_description;
            $arr[$row->abbr]['description'] = $row->description;
            $arr[$row->abbr]['price'] = $row->price;
            $arr[$row->abbr]['old_price'] = $row->old_price;
            $arr[$row->abbr]['dis_price'] = $row->dis_price;
            $arr[$row->abbr]['batch'] = $row->batch_no;
            $arr[$row->abbr]['mfd_dt'] = $row->mfd_date;
            $arr[$row->abbr]['exp_dt'] = $row->exp_date;
        }
        return $arr;
    }

}
